@@ -11,7 +11,7 @@ from .basic_commands import choose_from_list
 from .basic_commands import read_file
 from .basic_commands import write_file
 from .basic_commands import create_file_dir
-from .basic_commands import create_full_dir_path
+from .basic_commands import create_dirs
 from .basic_commands import remove_file_dir
 from .basic_commands import get_dir_path_for_file
 from .basic_commands import join_path
