@@ -1,11 +1,12 @@
-import traceback, json, sys, executing
+import json, sys, executing
 
+from traceback  import format_exc
 from functools  import wraps
 from textwrap   import dedent
 from shutil     import rmtree
 from typing     import Any, Optional
 from time   import perf_counter
-from os     import mkdir, listdir, remove
+from os     import mkdir, listdir, remove, makedirs
 
 
 class Timer:
@@ -130,7 +131,7 @@ def try_traceback(print_traceback=False):
                 return func(*args, **kwargs)
             except:
                 if print_traceback:
-                    fprint(traceback.format_exc())
+                    fprint(format_exc())
                 return None
         return wrapper
     return try_except
@@ -221,14 +222,13 @@ def enter_to_continue(text:str='', nl:bool=True, use_suffix:bool=True) -> bool:
     return not any(inpt)
 
 
-def fprint_array(arr, header:str='', indx_brackets:str='[]', start_num:int=0, nl:bool=True) -> None:
+def fprint_array(arr, header:str='', indx_brackets:str='[]', print_num=False, start_num:int=0, nl:bool=True) -> None:
     """This function prints the elements of an array along with their index numbers.
 
     Parameters:
     - `arr` (`list`|`set`|`tuple`|`dict`): The input array whose elements are to be printed.
-    - `header` (str): Header message to be printed before the array elements. Default is ''.
-    - `indx_brackets` (str): Type of brackets to be used for index numbers. Default is '`[]`'.
-    - `start_num` (int): Starting index number for printing elements. Default is 0.
+    - `header` (str):  The header message to be printed before the array elements. Defaults is ''.
+    - `indx_brackets` (str): The type of brackets to be used for index numbers. Defaults is '`[]`'.
     - `nl` (bool): Whether to append a newline character after the input.
     
     Returns:
@@ -252,29 +252,43 @@ def fprint_array(arr, header:str='', indx_brackets:str='[]', start_num:int=0, nl
 
         return inpt_array_name
 
+
+    def _print_output(text):
+        if text.__class__.__name__ == 'dict':
+            return fprint_array(text, header=header, indx_brackets=indx_brackets, print_num=print_num, start_num=start_num, nl=nl)
+
+        if print_num:
+            print(f'{config_indx_num(indx)} {text}')
+        else:
+            print(text)
+
     config_indx_num = lambda indx : f'{indx_brackets[0]}{indx}{indx_brackets[1]}'
 
     arr_type = arr.__class__.__name__
-    
-    if arr_type not in 'list set tuple dict'.split():
-        arr_name = _get_array_name()
-        print(f'Given array ({arr_name}) is not a valid format: {arr_type}')
-        return
-
-    if header:
-        print(header)
 
     match arr_type:
         case 'list' | 'set' | 'tuple':
+            if not arr:
+                print(f'Array is empty: {_get_array_name()}')
+                return
+
+            if header:
+                print(header)
+
             for indx, value in enumerate(arr, start=start_num):
-                print(f'{config_indx_num(indx)} {value}')
+                _print_output(value)
+
+            if nl:
+                print()
 
         case 'dict':
             for indx, (key, value) in enumerate(arr.items(), start=start_num):
-                print(f'{config_indx_num(indx)} {key}: {value}')
+                _print_output(f'{key}: {value}')
 
-    if nl:
-        print()
+        case _:
+            arr_name = _get_array_name()
+            print(f'Given array ({arr_name}) is not a valid format: {arr_type}')
+            return
 
 
 def choose_from_list(_array:Any, header_text:str='', header_nl:bool=False, input_text:str='Input index: ', choose_total:int=1, start_num:int=0, choose_until_correct:bool=True) -> list:
@@ -406,7 +420,7 @@ def write_file(text:Any, file_path:str, append:bool=False, force_create:bool=Tru
     except IndexError:
         pass
     except Exception:
-        fprint(traceback.format_exc(), do_print=do_print)
+        fprint(format_exc(), do_print=do_print)
 
     if append:
         mode = 'a'
@@ -466,14 +480,32 @@ def create_file_dir(do:str, do_path:str, force:bool=False, do_print:bool=True) -
                 return False
 
 
-def create_full_dir_path(dir_path:str, force:bool=False, do_print:bool=True) -> bool:
-    dir_path = dir_path.replace('\\', '/')
+def create_dirs(dst_path:str, do_print:bool=True) -> bool:
+    """Create all required directories for the given path.
+    
+    Parameters:
+    - `dst_path` (str): Destination path; can include the file name at the end
+    
+    Returns:
+    - `bool`: If all directories were created or not"""
 
-    dir_path_lst = dir_path.split('/')
-    for dir_indx, dir in enumerate(dir_path_lst):
-        was_created = create_file_dir('d', '/'.join(dir_path_lst[:dir_indx+1]), force, do_print)
+    if dst_path == '':
+        return False
 
-    return was_created
+    _dst_path = get_dir_path_for_file(dst_path, ret_val='d', do_print=do_print)
+
+    try:
+        makedirs(_dst_path)
+        fprint(f'Destination created for path: {_dst_path}', do_print=do_print)
+        return True
+
+    except FileExistsError:
+        fprint(f'Path already exists: {_dst_path}', do_print=do_print)
+
+    except Exception:
+        fprint(format_exc(), do_print=do_print)
+    
+    return False
 
 
 @try_traceback(print_traceback=True)
@@ -651,7 +683,7 @@ def read_json(file_path:str, do_print:bool=True) -> Any:
     except json.decoder.JSONDecodeError:
         fprint(f'File cannot be read as a JSON: {file_path}', do_print=do_print)
     except Exception:
-        fprint(traceback.format_exc(), do_print=do_print)
+        fprint(format_exc(), do_print=do_print)
 
 
 def write_json(data:Any, file_path:str, indent:int=4, force:bool=False, do_print:bool=True):
@@ -686,5 +718,5 @@ def write_json(data:Any, file_path:str, indent:int=4, force:bool=False, do_print
     except TypeError:
         fprint(f'Data type is wrong, can\'t write to JSON: {data.__class__.__name__}', do_print=do_print)
     except Exception:
-        fprint(traceback.format_exc())
+        fprint(format_exc())
     return False
\ No newline at end of file
